@@ -62,6 +62,10 @@ GType ide_symbol_flags_get_type (void);
 GType ide_thread_pool_kind_get_type (void);
 #define IDE_TYPE_THREAD_POOL_KIND (ide_thread_pool_kind_get_type ())
 
+/* enumerations from "./transfers/ide-transfer.h" */
+GType ide_transfer_error_get_type (void);
+#define IDE_TYPE_TRANSFER_ERROR (ide_transfer_error_get_type ())
+
 /* enumerations from "./vcs/ide-vcs-config.h" */
 GType ide_vcs_config_type_get_type (void);
 #define IDE_TYPE_VCS_CONFIG_TYPE (ide_vcs_config_type_get_type ())
